use serde::Serialize;

#[derive(Serialize, Debug)]
pub struct Contour {}

#[derive(Serialize, Debug)]
pub struct HeatMap {}

#[derive(Serialize, Debug)]
pub struct ParallelCoordinates {}
